@@ -50,7 +50,7 @@ def yamlValidation():
             Config.sast_lang = Config.config_data['SAST']['language'].split(",") ## comma sperated if mulitple
             
             Config.sast_present = True
-
+            Config.sast_message = 'SAST is properly configured'
             logging.info('SAST is properly configured with %s and ready to scan',Config.sast_lang)
 
             try:
@@ -65,8 +65,11 @@ def yamlValidation():
             except KeyError: 
                 logging.error('Java requires a target file to be mentioned in the boman.yaml file. refer the documentation')
                 Config.sast_present = False       
+                Config.sast_message = 'SAST is not configured properly, Java requires a target file to be mentioned in the boman.yaml file. refer the documentation'    
+
     except KeyError:    
         Config.sast_present = False
+        Config.sast_message = 'SAST was not properly defined in the config, Please check your boman.yaml file.'
         logging.warning('SAST was not properly defined in the config')
         logging.warning('Ignoring SAST, Please provide all mandatory inputs incase you like to run SAST scan.')
         
@@ -97,6 +100,7 @@ def yamlValidation():
                 
     except KeyError:    
         Config.dast_present = False
+        Config.dast_message = 'DAST was not properly defined in the config, Please check your boman.yaml file.'
         logging.warning('DAST was not properly defined in the config.')
         logging.warning('Ignoring DAST, Please provide all mandatory inputs incase you like to run DAST scan.')
         
@@ -116,13 +120,15 @@ def yamlValidation():
             except KeyError: 
                 Config.sca_build_dir = os.getcwd()+'/'
 
+            Config.sca_message ='SCA is properly configured'
             logging.info('SCA is properly configured and ready to scan')    
     except KeyError:    
         Config.sca_present =  False
+        Config.sca_message ='SCA was not properly defined in the config'
         logging.warning('SCA was not properly defined in the config')
         logging.warning('Ignoring SCA, Please provide all mandatory inputs incase you like to run SCA scan.')
         
-##secret scann
+#ss
     try:
         if Config.config_data['Secret_Scan'] == False:
             Config.secret_scan_present = False
@@ -137,15 +143,20 @@ def yamlValidation():
 
                 if Config.secret_scan_present:
                     logging.info('Secret scanning is properly configured and ready to scan')
+                    Config.secret_scan_message ='Secret scanning is properly configured and ready to scan'
                 else:
                     logging.warning('Secret scanning is properly configured, but working directory is not a git repository.') 
-                    logging.warning('Ignoring Secret scanning.')                 
+                    logging.warning('Ignoring Secret scanning.')    
+                    Config.secret_scan_message ='Secret scanning is properly configured, but working directory is not a git repository.'       
             except KeyError:
                 Config.secret_scan_present = False
                 logging.warning('Secret scanning is not properly configured, Working directory is not git.') 
+                Config.secret_scan_message ='Secret scanning is not properly configured'     
     except KeyError:
         Config.secret_scan_present = False  
         logging.warning('Secret scanning is not properly configured. Cant read the Secret_Scan configuration.')   
+        Config.secret_scan_message ='Secret scanning is not properly configured'  
+
 
         
 
